\name{rpucor.test}
\alias{rpucor.test}
\alias{rpucor.test.default}
\concept{Kendall correlation coefficient}
\concept{Kendall's tau}
\title{Compute the p-values of the correlation matrix}

\description{
This function computes the p-values of the correlation matrix of two multivariate statistics.
Current implementation supports only finding p-values of the Kendall Tau-b coefficient.
}

\usage{
rpucor.test(x, \dots)

\method{rpucor.test}{default}(x, y = NULL,
    alternative = c("two.sided", "less", "greater"),
    use = "everything", method = "kendall", \dots)
}

\arguments{
    \item{x}{a numeric vector, matrix or data frame. } 

    \item{y}{a vector, matrix or data frame with compatible dimensions to 'x'. 
        The default 'NULL' value is equivalent to 'y = x'. } 

    \item{alternative}{a string representing the alternative hypothesis.
        It must be one of the following: \code{"two.sided"}(default), 
        \code{"less"}, or \code{"greater"}.}
      
    \item{use}{a string representing the method to handle missing values.  
        Currently supported values are: \code{"everything"}(default), 
        \code{"all.obs"}, \code{"complete.obs"}, \code{"na.or.complete"}, or 
        \code{"pairwise.complete.obs"}.}

    \item{method}{a string representing the name of the correlation to be
        computed.  Currently, the only supported value is \code{"kendall"}.}

    \item{\dots}{further arguments to be passed to or from methods.}
        
}

\details{
    Compute the p-values of the Kendall Tau-b correlation with GPU 
    using the rpudplus add-on for rpud. 
}

\value{
    A list of class \code{"rpucor.test"} containing the following:
    
    \item{statistic}{matrix of the Z statistics.} 
    
    \item{p.value}{matrix of the p-values.} 
    
    \item{estimate}{matrix of the correlation coefficient.} 
    
    \item{null.value}{the zero value for the null hypothesis.} 
    
    \item{alternative}{a string representing the alternative hypothesis.} 
    
    \item{method}{the correlation method.} 
    
    \item{use}{the method to handle the missing values.} 
    
    \item{data.name}{a string representing the input data.} 
}

\seealso{
    rpucor, cor.test
}

\examples{
\dontrun{

num <- 5
dim1 <- 6
dim2 <- 8
x <- matrix(runif(num*dim1), num, dim1)
y <- matrix(runif(num*dim2), num, dim2)
rpucor.test(x, y, method = "kendall")

# introduce missing values
x[3,5] <- NA
y[4,1] <- NA
rpucor.test(x, y, method = "kendall", use="pairwise.complete.obs")

}}

\keyword{multivariate}
\keyword{correlation}


